package VMOMI::CustomizationNetBIOSMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
